yt.data_objects.selection_data_containers.YTEllipsoidBase.extract_connected_sets — The yt Project 3.2-dev documentation

# yt.data_objects.selection_data_containers.YTEllipsoidBase.extract_connected_sets

`YTEllipsoidBase.` `extract_connected_sets`(field, num_levels, min_val, max_val, log_space=True, cumulative=True)

  This function will create a set of contour objects, defined by having connected cell structures, which can then be studied and used to ‘paint’ their source grids, thus enabling them to be plotted.

  Note that this function can return a connected set object that has no member values.